@@ -25,7 +25,7 @@ class BaseModule:
             library_name (str): VHDL library name.
             default_registers (list(Register)): Default registers.
         """
-        self.path = path
+        self.path = path.resolve()
         self.name = path.name
         self.library_name = library_name
 
@@ -200,6 +200,16 @@ class BaseModule:
         """
         return []
 
+    @staticmethod
+    def generics_to_string(generics):
+        """
+        Pack generics in a string. Useful for naming test cases and build projects.
+
+        Args:
+            generics (dict): Generic values to be packed.
+        """
+        return ".".join([f"{key}_{value}" for key, value in generics.items()])
+
     def __str__(self):
         return f"{self.name}:{self.path}"
 
